from ._uirevision import UirevisionValidator
from ._orientation import OrientationValidator
from ._color import ColorValidator
from ._bgcolor import BgcolorValidator
from ._activecolor import ActivecolorValidator
